@@ -4,12 +4,28 @@
 # include <config.h>
 #endif
 
+#ifdef WIN32
+# include <sys/types.h>
+# include <malloc.h>
+# define HAVE_MEMMOVE
+# define HAVE_MEMSET
+# define STDC_HEADERS
+#endif
+
+
 #ifdef STDC_HEADERS
 # include <string.h>
 # include <stdlib.h>
 # include <stdio.h>
 #endif
 
+#ifdef WIN32
+# include <windows.h>
+# include <string.h>
+# include <sys/types.h>
+# include <malloc.h>
+#endif
+
 #ifdef HAVE_STRINGS_H
 # include <strings.h>
 #endif
@@ -25,7 +41,9 @@
  typedef unsigned int word32;
  typedef signed int sword32;
 #else
-# error "Cannot find a 32 bit integer in your system, sorry."
+# warn "Cannot find a 32 bit integer in your system. Using defaults."
+ typedef unsigned int word32;
+ typedef signed int sword32; 
 #endif
 
 #if SIZEOF_UNSIGNED_INT == 2
@@ -33,13 +51,15 @@
 #elif SIZEOF_UNSIGNED_SHORT_INT == 2
  typedef unsigned short word16;
 #else 
-# error "Cannot find a 16 bit integer in your system, sorry."
+# warn "Cannot find a 16 bit integer in your system. Using defaults."
+ typedef unsigned short word16;
 #endif
 
 #if SIZEOF_UNSIGNED_CHAR == 1
  typedef unsigned char word8; 
 #else
-# error "Cannot find an 8 bit char in your system, sorry."
+# warn "Cannot find an 8 bit char in your system. Using defaults"
+ typedef unsigned char word8; 
 #endif
 
 /* originally was in 3way.c */
